==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class EndpointsBuilder extends EndpointsFluentImpl<EndpointsBuilder> implements VisitableBuilder<Endpoints,EndpointsBuilder>{

    EndpointsFluent<?> fluent;
    Boolean validationEnabled;

    public EndpointsBuilder(){
            this(true);
    }
    public EndpointsBuilder(Boolean validationEnabled){
            this(new Endpoints(), validationEnabled);
    }
    public EndpointsBuilder(EndpointsFluent<?> fluent){
            this(fluent, true);
    }
    public EndpointsBuilder(EndpointsFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new Endpoints(), validationEnabled);
    }
    public EndpointsBuilder(EndpointsFluent<?> fluent,Endpoints instance){
            this(fluent, instance, true);
    }
    public EndpointsBuilder(EndpointsFluent<?> fluent,Endpoints instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            fluent.withSubsets(instance.getSubsets()); 
            this.validationEnabled = validationEnabled; 
    }
    public EndpointsBuilder(Endpoints instance){
            this(instance,true);
    }
    public EndpointsBuilder(Endpoints instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSubsets(instance.getSubsets()); 
            this.validationEnabled = validationEnabled; 
    }

    public Endpoints build(){
            Endpoints buildable = new Endpoints(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSubsets());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            EndpointsBuilder that = (EndpointsBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-2.0.9-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EndpointsBuilder extends EndpointsFluentImpl<EndpointsBuilder> implements VisitableBuilder<Endpoints,EndpointsBuilder>{

    EndpointsFluent<?> fluent;
    Boolean validationEnabled;

    public EndpointsBuilder(){
            this(true);
    }
    public EndpointsBuilder(Boolean validationEnabled){
            this(new Endpoints(), validationEnabled);
    }
    public EndpointsBuilder(EndpointsFluent<?> fluent){
            this(fluent, true);
    }
    public EndpointsBuilder(EndpointsFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new Endpoints(), validationEnabled);
    }
    public EndpointsBuilder(EndpointsFluent<?> fluent,Endpoints instance){
            this(fluent, instance, true);
    }
    public EndpointsBuilder(EndpointsFluent<?> fluent,Endpoints instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            fluent.withSubsets(instance.getSubsets()); 
            this.validationEnabled = validationEnabled; 
    }
    public EndpointsBuilder(Endpoints instance){
            this(instance,true);
    }
    public EndpointsBuilder(Endpoints instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSubsets(instance.getSubsets()); 
            this.validationEnabled = validationEnabled; 
    }

    public Endpoints build(){
            Endpoints buildable = new Endpoints(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSubsets());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            EndpointsBuilder that = (EndpointsBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
